<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>InvertSelection</name>
    <message>
        <location filename="../InvertSelectionInit.js" line="+2"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Invertovat výběr</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Invert the current selection</source>
        <translation>Invertovat aktuální výběr</translation>
    </message>
</context>
</TS>
